@@ -1,19 +1,24 @@
 QR.lasso.mm = function(X,y,tau,lambda,beta,maxit,toler)
 {
 
-if(nargs()<6){
+if(missing(toler)){
 	toler = 1e-3
-	maxit = 200
+	
 }
 
+if(missing(maxit)){
+maxit = 200
+}
+
+
 n=dim(X)[1]
 x=cbind(rep(1,n),X)
 
-if(nargs()<5){
+if(missing(beta)){
 	beta=solve(t(x)%*%x,t(x)%*%y)
 }
 
-if(nargs()<4){
+if(missing(lambda)){
 	lambda=1
 }
 
